var NAVTREEINDEX13 =
{
"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[27,0,0,284],
"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[26,0,0,284],
"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[27,0,0,285],
"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[26,0,0,285],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[27,0,0,286],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[26,0,0,286],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[27,0,0,287],
"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[26,0,0,287],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,288],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[26,0,0,288],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,289],
"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,289],
"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,290],
"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[26,0,0,290],
"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,291],
"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,291],
"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[26,0,0,292],
"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[27,0,0,292],
"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[27,0,0,293],
"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[26,0,0,293],
"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[27,0,0,294],
"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[26,0,0,294],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[27,0,0,295],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[26,0,0,295],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[27,0,0,296],
"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[26,0,0,296],
"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[27,0,0,297],
"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[26,0,0,297],
"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[27,0,0,298],
"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[26,0,0,298],
"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,299],
"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,299],
"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,300],
"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[26,0,0,300],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[27,0,1,0],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[27,0,1,1],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[27,0,1,2],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__is__enabled.html":[27,0,1,3],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__set.html":[27,0,1,4],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__rank.html":[27,0,1,5],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__size.html":[27,0,1,6],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__disable.html":[27,0,1,7],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__enable.html":[27,0,1,8],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__comm__stats__retrieve.html":[27,0,1,9],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__get__rank.html":[27,0,1,10],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__get__tag.html":[27,0,1,11],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__migrate.html":[27,0,1,12],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__register.html":[27,0,1,13],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__register__comm.html":[27,0,1,14],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__selection__get__current__policy.html":[27,0,1,15],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__selection__set__current__policy.html":[27,0,1,16],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__rank.html":[27,0,1,17],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__rank__comm.html":[27,0,1,18],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__data__set__tag.html":[27,0,1,19],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__datatype__register.html":[27,0,1,20],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__datatype__unregister.html":[27,0,1,21],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__gather__detached.html":[27,0,1,22],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__communication__tag.html":[27,0,1,23],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__data__on__node.html":[27,0,1,24],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__get__data__on__node__detached.html":[27,0,1,25],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__insert__task.html":[27,0,1,26],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__irecv.html":[27,0,1,27],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend.html":[27,0,1,28],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__array__detached__unlock__tag.html":[27,0,1,29],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__array__detached__unlock__tag__prio.html":[27,0,1,30],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached.html":[27,0,1,31],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__prio.html":[27,0,1,32],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__unlock__tag.html":[27,0,1,33],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__unlock__tag__prio.html":[27,0,1,34],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__prio.html":[27,0,1,35],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend.html":[27,0,1,36],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__detached.html":[27,0,1,37],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__detached__prio.html":[27,0,1,38],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__issend__prio.html":[27,0,1,39],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__node__selection__register__policy.html":[27,0,1,40],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__node__selection__unregister__policy.html":[27,0,1,41],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv.html":[27,0,1,42],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__array__detached__unlock__tag.html":[27,0,1,43],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached.html":[27,0,1,44],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached__sequential__consistency.html":[27,0,1,45],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached__unlock__tag.html":[27,0,1,46],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data.html":[27,0,1,47],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data__prio.html":[27,0,1,48],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data__prio__tree.html":[27,0,1,49],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data__tree.html":[27,0,1,50],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__req__alloc.html":[27,0,1,51],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__req__free.html":[27,0,1,52],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__scatter__detached.html":[27,0,1,53],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__send.html":[27,0,1,54],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__send__prio.html":[27,0,1,55],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__set__communication__tag.html":[27,0,1,56],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__shutdown.html":[27,0,1,57],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__status__alloc.html":[27,0,1,58],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__status__free.html":[27,0,1,59],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__build.html":[27,0,1,60],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__insert.html":[27,0,1,61],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__post__build.html":[27,0,1,62],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__test.html":[27,0,1,63],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__wait.html":[27,0,1,64],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__wait__for__all.html":[27,0,1,65],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__comm.html":[27,0,1,66],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__rank.html":[27,0,1,67],
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__world__size.html":[27,0,1,68],
"interfacestarpu__mod_1_1starpu__asynchronous__copy__disabled.html":[27,0,2,0],
"interfacestarpu__mod_1_1starpu__asynchronous__cuda__copy__disabled.html":[27,0,2,1],
"interfacestarpu__mod_1_1starpu__asynchronous__opencl__copy__disabled.html":[27,0,2,2],
"interfacestarpu__mod_1_1starpu__conf__init.html":[27,0,2,3],
"interfacestarpu__mod_1_1starpu__cpu__worker__get__count.html":[27,0,2,4],
"interfacestarpu__mod_1_1starpu__display__stats.html":[27,0,2,5],
"interfacestarpu__mod_1_1starpu__get__version.html":[27,0,2,6],
"interfacestarpu__mod_1_1starpu__init.html":[27,0,2,7],
"interfacestarpu__mod_1_1starpu__pause.html":[27,0,2,8],
"interfacestarpu__mod_1_1starpu__resume.html":[27,0,2,9],
"interfacestarpu__mod_1_1starpu__shutdown.html":[27,0,2,10],
"interfacestarpu__mod_1_1starpu__task__wait__for__all.html":[27,0,2,11],
"modules.html":[25],
"namespacefstarpu__mod.html#interfacefstarpu__mod_1_1operator_07_8ior_8_08":[28,0,1,1,0],
"namespaces.html":[26,0],
"pages.html":[],
"sc__hypervisor_8h.html":[28,0,3,0,0],
"sc__hypervisor_8h_source.html":[28,0,3,0,0],
"sc__hypervisor__config_8h.html":[28,0,3,0,1],
"sc__hypervisor__config_8h.html#a002798d04e272d4901e06d2909e2d970":[28,0,3,0,1,0,4],
"sc__hypervisor__config_8h.html#a1c071ab4625b8a98fcce0b3ceebccad9":[28,0,3,0,1,0,10],
"sc__hypervisor__config_8h.html#a210d14a5cc6487ffdc76ae35c6a16edb":[28,0,3,0,1,0,7],
"sc__hypervisor__config_8h.html#a3cfede397206c8e6766f5fe8fcfd1fef":[28,0,3,0,1,0,9],
"sc__hypervisor__config_8h.html#a635e8967fa211c34d367c471b847e3c7":[28,0,3,0,1,0,3],
"sc__hypervisor__config_8h.html#a78e03b1cc0e5f7505bb7f0404955d239":[28,0,3,0,1,0,2],
"sc__hypervisor__config_8h.html#a963cb56195d9fa30e905a4d1ba0c4300":[28,0,3,0,1,0,1],
"sc__hypervisor__config_8h.html#a9e0d3d7192aa552436227f5886dc0075":[28,0,3,0,1,0,0],
"sc__hypervisor__config_8h.html#ab2ceb91193882e327559323f3669262b":[28,0,3,0,1,0,6],
"sc__hypervisor__config_8h.html#ac56775b3eafc46d10aaf2162676b72d0":[28,0,3,0,1,0,8],
"sc__hypervisor__config_8h.html#afdb68c657fb202f52938f5268749003d":[28,0,3,0,1,0,5],
"sc__hypervisor__config_8h.html#structsc__hypervisor__policy__config":[28,0,3,0,1,0],
"sc__hypervisor__config_8h_source.html":[28,0,3,0,1],
"sc__hypervisor__lp_8h.html":[28,0,3,0,2],
"sc__hypervisor__lp_8h_source.html":[28,0,3,0,2],
"sc__hypervisor__monitoring_8h.html":[28,0,3,0,3],
"sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6":[28,0,3,0,3,0,22],
"sc__hypervisor__monitoring_8h.html#a0786fc47b4d17d660cfe66649e4933e7":[28,0,3,0,3,0,9],
"sc__hypervisor__monitoring_8h.html#a0cd92328373b9b5427e6bb48a44d8644":[28,0,3,0,3,0,2],
"sc__hypervisor__monitoring_8h.html#a10b881331a3075f0d1508ee96b0dd50a":[28,0,3,0,3,0,19],
"sc__hypervisor__monitoring_8h.html#a1c6e13064c46813ec41b453acd0174d4":[28,0,3,0,3,0,14],
"sc__hypervisor__monitoring_8h.html#a1e0e2c4e5a03176a09fe4f84a4b5a1ee":[28,0,3,0,3,0,27],
"sc__hypervisor__monitoring_8h.html#a3a8cc8e96001231da38e869e324ce22e":[28,0,3,0,3,0,5],
"sc__hypervisor__monitoring_8h.html#a45b953429183c5a75c83a691d8339e7a":[28,0,3,0,3,0,17],
"sc__hypervisor__monitoring_8h.html#a4aa40a61865a2e10a161b5e8148560bb":[28,0,3,0,3,0,13],
"sc__hypervisor__monitoring_8h.html#a4c01108a62fd573f2a6430381ce7943f":[28,0,3,0,3,0,10],
"sc__hypervisor__monitoring_8h.html#a670c50b3b52c05d3ca95e8717f1b4a6b":[28,0,3,0,3,0,3],
"sc__hypervisor__monitoring_8h.html#a6c2b7e686bd8a6257184688a4e4d52eb":[28,0,3,0,3,0,12],
"sc__hypervisor__monitoring_8h.html#a719b6c515fdb98ad09f549048cc9caa3":[28,0,3,0,3,0,6],
"sc__hypervisor__monitoring_8h.html#a7ed3efcd3b7e2886f5610e5f5920eb99":[28,0,3,0,3,0,1],
"sc__hypervisor__monitoring_8h.html#a8923658556a212b0ed82f2138a4c5850":[28,0,3,0,3,0,7],
"sc__hypervisor__monitoring_8h.html#aa72bfdedf5238e9faaee87f48d72bebe":[28,0,3,0,3,0,20],
"sc__hypervisor__monitoring_8h.html#ab35accf0d5a3a49c1ab43799aad115bb":[28,0,3,0,3,0,0],
"sc__hypervisor__monitoring_8h.html#aba3d21edf846f13f3d41405ab7d99016":[28,0,3,0,3,0,21],
"sc__hypervisor__monitoring_8h.html#abe9c30e847ed5dab431ffb1e753b4829":[28,0,3,0,3,0,15],
"sc__hypervisor__monitoring_8h.html#abf552a3af2c6928c9f4e0dd6e845c7e0":[28,0,3,0,3,0,26],
"sc__hypervisor__monitoring_8h.html#acd3f606a760909b7b7262b2927c537b3":[28,0,3,0,3,0,18],
"sc__hypervisor__monitoring_8h.html#adfb3d97bbdc15b0f9acee62ab4ae6350":[28,0,3,0,3,0,8],
"sc__hypervisor__monitoring_8h.html#adfbc9bbc2fb020e1b0c847f8557e45d6":[28,0,3,0,3,0,24],
"sc__hypervisor__monitoring_8h.html#ae52f8e1b8fdfd299a91890cef366a00a":[28,0,3,0,3,0,23],
"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d":[28,0,3,0,3,0,28],
"sc__hypervisor__monitoring_8h.html#aee6c9636c4ce6692556e0e87e4d16455":[28,0,3,0,3,0,11],
"sc__hypervisor__monitoring_8h.html#aeffa224cc0e8e84dcc4decb64f2cb54c":[28,0,3,0,3,0,16],
"sc__hypervisor__monitoring_8h.html#aeffdde67d260b4ab8e18a625055ec7c0":[28,0,3,0,3,0,4],
"sc__hypervisor__monitoring_8h.html#afaf7aa117a0cf782337d67ae6ea0f961":[28,0,3,0,3,0,25],
"sc__hypervisor__monitoring_8h.html#structsc__hypervisor__wrapper":[28,0,3,0,3,0],
"sc__hypervisor__monitoring_8h_source.html":[28,0,3,0,3],
"sc__hypervisor__policy_8h.html":[28,0,3,0,4],
"sc__hypervisor__policy_8h_source.html":[28,0,3,0,4],
"starpu_8h.html":[28,0,1,2],
"starpu_8h_source.html":[28,0,1,2],
"starpu__bitmap_8h.html":[28,0,1,3],
"starpu__bitmap_8h.html#structstarpu__bitmap":[28,0,1,3,0],
"starpu__bitmap_8h_source.html":[28,0,1,3],
"starpu__bound_8h.html":[28,0,1,4],
"starpu__bound_8h_source.html":[28,0,1,4],
"starpu__config_8h.html":[28,0,0,0],
"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[28,0,0,0,12],
"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[28,0,0,0,29],
"starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[28,0,0,0,5],
"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[28,0,0,0,28],
"starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[28,0,0,0,4],
"starpu__config_8h_source.html":[28,0,0,0],
"starpu__cublas_8h.html":[28,0,1,5],
"starpu__cublas_8h_source.html":[28,0,1,5],
"starpu__cublas__v2_8h.html":[28,0,1,6],
"starpu__cublas__v2_8h_source.html":[28,0,1,6],
"starpu__cuda_8h.html":[28,0,1,7],
"starpu__cuda_8h_source.html":[28,0,1,7],
"starpu__cusolver_8h.html":[28,0,1,8],
"starpu__cusolver_8h.html#a370a7a73030f807605a9b5e418e29852":[28,0,1,8,3],
"starpu__cusolver_8h.html#a661622267516b78a8c71c60fa8a27c4a":[28,0,1,8,6],
"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434":[28,0,1,8,5],
"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e":[28,0,1,8,4],
"starpu__cusolver_8h.html#aa27808f9256c0b90c2c231b598b16220":[28,0,1,8,0],
"starpu__cusolver_8h.html#adc9d0c6e8728152c6ede31a828c353a6":[28,0,1,8,2],
"starpu__cusolver_8h_source.html":[28,0,1,8],
"starpu__cusparse_8h.html":[28,0,1,9],
"starpu__cusparse_8h_source.html":[28,0,1,9],
"starpu__data_8h.html":[28,0,1,10],
"starpu__data_8h_source.html":[28,0,1,10],
"starpu__data__filters_8h.html":[28,0,1,11],
"starpu__data__filters_8h_source.html":[28,0,1,11],
"starpu__data__interfaces_8h.html":[28,0,1,12],
"starpu__data__interfaces_8h_source.html":[28,0,1,12],
"starpu__deprecated__api_8h.html":[28,0,1,13],
"starpu__deprecated__api_8h_source.html":[28,0,1,13],
"starpu__disk_8h.html":[28,0,1,14],
"starpu__disk_8h_source.html":[28,0,1,14],
"starpu__driver_8h.html":[28,0,1,15],
"starpu__driver_8h_source.html":[28,0,1,15],
"starpu__expert_8h.html":[28,0,1,16],
"starpu__expert_8h_source.html":[28,0,1,16],
"starpu__fxt_8h.html":[28,0,1,17],
"starpu__fxt_8h_source.html":[28,0,1,17],
"starpu__hash_8h.html":[28,0,1,18],
"starpu__hash_8h_source.html":[28,0,1,18],
"starpu__helper_8h.html":[28,0,1,19],
"starpu__helper_8h_source.html":[28,0,1,19],
"starpu__heteroprio_8h.html":[28,0,1,0,0],
"starpu__heteroprio_8h_source.html":[28,0,1,0,0],
"starpu__hip_8h.html":[28,0,1,20],
"starpu__hip_8h_source.html":[28,0,1,20],
"starpu__max__fpga_8h.html":[28,0,1,21],
"starpu__max__fpga_8h_source.html":[28,0,1,21],
"starpu__mod_8f90.html":[28,0,1,22],
"starpu__mpi_8h.html":[28,0,2,0,0],
"starpu__mpi_8h_source.html":[28,0,2,0,0],
"starpu__mpi__ft_8h.html":[28,0,2,0,1],
"starpu__mpi__ft_8h_source.html":[28,0,2,0,1],
"starpu__mpi__lb_8h.html":[28,0,2,0,2],
"starpu__mpi__lb_8h.html#a1692d18d1d2d0df9eae6c148d54167f1":[28,0,2,0,2,1],
"starpu__mpi__lb_8h_source.html":[28,0,2,0,2],
"starpu__opencl_8h.html":[28,0,1,23],
"starpu__opencl_8h_source.html":[28,0,1,23],
"starpu__openmp_8h.html":[28,0,1,24],
"starpu__openmp_8h_source.html":[28,0,1,24],
"starpu__parallel__worker_8h.html":[28,0,1,25],
"starpu__parallel__worker_8h_source.html":[28,0,1,25],
"starpu__perf__monitoring_8h.html":[28,0,1,26],
"starpu__perf__monitoring_8h_source.html":[28,0,1,26],
"starpu__perf__steering_8h.html":[28,0,1,27],
"starpu__perf__steering_8h_source.html":[28,0,1,27],
"starpu__perfmodel_8h.html":[28,0,1,28],
"starpu__perfmodel_8h_source.html":[28,0,1,28],
"starpu__profiling_8h.html":[28,0,1,29],
"starpu__profiling_8h_source.html":[28,0,1,29],
"starpu__profiling__tool_8h.html":[28,0,1,30]
};
